@@ -16,16 +16,11 @@ class TTS:
         self.gen = None
         self.voice = None
         self.preset = "ultra_fast"
-        self.tts = TextToSpeech(autoregressive_batch_size=16)
+        self.tts = TextToSpeech(autoregressive_batch_size=1)
         self.voice_samples_gabby_reading, self.conditioning_latent_reading = \
             load_voice("gabby_reading")
         self.voice_samples_gabby_convo, self.conditioning_latent_convo = \
             load_voice("gabby_convo")
-        BUILTIN_LATENT_DIR = os.path.join(os.path.dirname(os.path.realpath(__file__)), "data")
-
-        with open(os.path.join(BUILTIN_LATENT_DIR, 'latents.pkl'), 'rb') as f:
-            self.conditioning_latent_reading = pickle.load(f)
-
 
     def generate(self, text, voice: Text = "gabby_reading"):
         if voice == "gabby_reading":
@@ -33,14 +28,14 @@ class TTS:
                                        conditioning_latents=self.conditioning_latent_reading,
                                        use_deterministic_seed=0,
                                        return_deterministic_state=True,
-                                       num_autoregressive_samples=16,
+                                       num_autoregressive_samples=1,
                                        diffusion_iterations=30)
         else:
             self.gen, _ = self.tts.tts(text,
                                        conditioning_latents=self.conditioning_latent_convo,
                                        use_deterministic_seed=0,
                                        return_deterministic_state=True,
-                                       num_autoregressive_samples=16,
+                                       num_autoregressive_samples=1,
                                        diffusion_iterations=30)
 
     def parse(self):
